<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Form;

use Laminas\Form\Form;

class EmailMessageForm extends Form
{
    public function __construct($name = 'email-message-form', array $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        /*=============================需要多语言处理=============================*/
        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'textarea',
                'name'  => 'addOrderEmailBody'.$language,
                'attributes'    => [
                    'id'    => 'addOrderEmailBody'.$language,
                    'class' => 'form-control',
                    'rows'  => 6
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'paymentOrderEmailBody'.$language,
                'attributes'    => [
                    'id'    => 'paymentOrderEmailBody'.$language,
                    'class' => 'form-control',
                    'rows'  => 6
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'shipOrderEmailBody'.$language,
                'attributes'    => [
                    'id'    => 'shipOrderEmailBody'.$language,
                    'class' => 'form-control',
                    'rows'  => 6
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'receiptOrderEmailBody'.$language,
                'attributes'    => [
                    'id'    => 'receiptOrderEmailBody'.$language,
                    'class' => 'form-control',
                    'rows'  => 6
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'cancelOrderEmailBody'.$language,
                'attributes'    => [
                    'id'    => 'cancelOrderEmailBody'.$language,
                    'class' => 'form-control',
                    'rows'  => 6
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'goodsStockOutEmailBody'.$language,
                'attributes'    => [
                    'id'    => 'goodsStockOutEmailBody'.$language,
                    'class' => 'form-control',
                    'rows'  => 6
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'virtualGoodsEmailBody'.$language,
                'attributes'    => [
                    'id'    => 'virtualGoodsEmailBody'.$language,
                    'class' => 'form-control',
                    'rows'  => 6
                ]
            ]);
        }

        $this->add([
            'type'  => 'textarea',
            'name'  => 'adminEmail',
            'attributes'    => [
                'id'    => 'adminEmail',
                'class' => 'form-control',
                'rows'  => 6
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'adminAddOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'buyerAddOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'adminPaymentOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'buyerPaymentOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'adminShipOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'buyerShipOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'adminReceiptOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'buyerReceiptOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'adminCancelOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'buyerCancelOrderSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'adminGoodsStockOutSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'adminVirtualGoodsSend',
            'attributes' => [
                'value' => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'buyerVirtualGoodsSend',
            'attributes' => [
                'value' => 1
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'addOrderEmailBody'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);

            $inputFilter->add([
                'name'      => 'paymentOrderEmailBody'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);


            $inputFilter->add([
                'name'      => 'shipOrderEmailBody'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);


            $inputFilter->add([
                'name'      => 'receiptOrderEmailBody'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);


            $inputFilter->add([
                'name'      => 'cancelOrderEmailBody'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);


            $inputFilter->add([
                'name'      => 'goodsStockOutEmailBody'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);


            $inputFilter->add([
                'name'      => 'virtualGoodsEmailBody'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'adminEmail',
            'required'  => false,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags']
            ]
        ]);

        $inputFilter->add([
            'name'      => 'adminAddOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'buyerAddOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'adminPaymentOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'buyerPaymentOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'adminShipOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'buyerShipOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'adminReceiptOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'buyerReceiptOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'adminCancelOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'buyerCancelOrderSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'adminGoodsStockOutSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'adminVirtualGoodsSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'buyerVirtualGoodsSend',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);
    }
}