<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Form;

use Admin\Data\Common;
use Admin\Data\Config;
use Admin\Filter\ImageThumb;
use Admin\Filter\OldImage;
use Admin\Validator\ImageSuffixValidator;
use Goods\Validator\GoodsClassValidator;
use Laminas\Form\Form;

class GoodsClassForm extends Form
{
    private $entityManager;
    private $goodsClass;

    public $inputFilter;

    public function __construct($entityManager = null, $goodsClass = null, $name = 'goods-class-form', array $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('enctype', 'multipart/form-data');
        $this->setAttribute('class', 'form-horizontal');

        $this->entityManager= $entityManager;
        $this->goodsClass   = $goodsClass;

        $this->addElements();
        $this->inputFilter = $this->addInputFilter();
    }

    protected function addElements()
    {
        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'className'.$language,
                'attributes'    => [
                    'id'            => 'className'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'classInfo'.$language,
                'attributes'    => [
                    'id'            => 'classInfo'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'classExtend'.$language,
                'attributes'    => [
                    'id'            => 'classExtend'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'classKeywords'.$language,
                'attributes'    => [
                    'id'            => 'classKeywords'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'classDescription'.$language,
                'attributes'    => [
                    'id'            => 'classDescription'.$language,
                    'class'         => 'form-control',
                    'rows'          => 4
                ]
            ]);
        }

        $this->add([
            'type'  => 'select',
            'name'  => 'classTopId',
            'attributes'    => [
                'id'            => 'classTopId',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'file',
            'name'  => 'classImage',
            'attributes'    => [
                'id'            => 'classImage',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'multiCheckbox',
            'name'  => 'classTagGroup',
            'options' => [
                'label_attributes' => [
                    'class' => 'checkbox-inline'
                ]
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'classState',
            'attributes'    => [
                'id'            => 'classState',
                'value'         => 1
            ]
        ]);

        $this->add([
            'type'  => 'number',
            'name'  => 'classSort',
            'attributes'    => [
                'id'            => 'classSort',
                'class'         => 'form-control',
                'value'         => 255
            ]
        ]);

    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'className'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 150
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'classInfo'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 3000
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'classExtend'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 255
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'classKeywords'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 255
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'classDescription'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 1000
                        ]
                    ]
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'classTopId',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => GoodsClassValidator::class,
                    'options'    => [
                        'entityManager' => $this->entityManager,
                        'goodsClass'    => $this->goodsClass
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'type'      => 'Laminas\InputFilter\FileInput',
            'name'      => 'classImage',
            'required'  => false,
            'validators'=> [
                ['name' => 'FileUploadFile'],
                ['name' => ImageSuffixValidator::class],
                [
                    'name' => 'FileMimeType',
                    'options' => [
                        'mimeType' => Common::configValue('image_type')
                    ]
                ],
                ['name' => 'FileIsImage'],
                [
                    'name' => 'FileSize',
                    'options' => Common::configValue('upload_image_max')
                ]
            ],
            'filters'  => [
                [
                    'name' => 'FileRenameUpload',
                    'options' => [
                        'target' => Config::GOODS_CLASS_IMAGE_PATH,
                        'useUploadName'=>true,
                        'useUploadExtension'=>true,
                        'overwrite'=>true,
                        'randomize' => true
                    ]
                ],
                [
                    'name' => ImageThumb::class,
                    'options' => [
                        'width' => Common::configValue('class_image_width'),
                        'height'=> Common::configValue('class_image_height'),
                        'mode'  => Common::configValue('class_image_crop')
                    ]
                ],
                [
                    'name' => OldImage::class,
                    'options' => [
                        'oldImage' => $this->goodsClass ? $this->goodsClass->getClassImage() : ''
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'classState',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'classTagGroup',
            'required'  => false
        ]);

        $inputFilter->add([
            'name'      => 'classSort',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);

        return $inputFilter;
    }
}