<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Service;

use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsContent;

class GoodsContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加和编辑商品内容
     * @param array $data
     * @param $goodsId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditGoodsContent(array $data, $goodsId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $goodsContent   = $this->entityManager->getRepository(GoodsContent::class)->findOneBy(['goodsId' => $goodsId, 'languageCode' => $language]);
            $emptyState     = false;
            if ($goodsContent == null) {
                $goodsContent = new GoodsContent();
                $goodsContent->setLanguageCode($language);
                $goodsContent->setGoodsId($goodsId);
                $emptyState = true;
            }
            $goodsContent->setGoodsName($data['goodsName'.$language]);
            $goodsContent->setGoodsExtendName($data['goodsExtendName'.$language]);
            $goodsContent->setGoodsBody($data['goodsBody'.$language]);
            $goodsContent->setGoodsKeywords($data['goodsKeywords'.$language]);
            $goodsContent->setGoodsDescription($data['goodsDescription'.$language]);

            if ($emptyState) $this->entityManager->persist($goodsContent);

            $this->entityManager->flush();
        }
    }

    /**
     * 删除商品内容
     * @param $goodsId
     * @return void
     */
    public function deleteGoodsContent($goodsId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsContent::class, 'c')->where($qb->expr()->eq('c.goodsId', $goodsId));
        $qb->getQuery()->execute();
    }
}