<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Service;

use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsTagContent;

class GoodsTagContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * @param array $data
     * @param $tagId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditTagContent(array $data, $tagId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $tagContent = $this->entityManager->getRepository(GoodsTagContent::class)->findOneBy(['tagId' => $tagId, 'languageCode' => $language]);
            if ($tagContent) {
                $tagContent->setTagName($data['tagName'.$language]);
            } else {
                $tagContent = new GoodsTagContent();
                $tagContent->setTagId($tagId);
                $tagContent->setLanguageCode($language);
                $tagContent->setTagName($data['tagName'.$language]);

                $this->entityManager->persist($tagContent);
            }

            $this->entityManager->flush();
        }
    }

    /**
     * 删除商品标签内容
     * @param $tagId
     * @return void
     */
    public function deleteGoodsTagContent($tagId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsTagContent::class, 'c')->where($qb->expr()->eq('c.tagId', $tagId));
        $qb->getQuery()->execute();
    }

    /**
     * 批量删除商品标签内容
     * @param $tagIdArray
     * @return void
     */
    public function deleteMoreGoodsTagContent($tagIdArray)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsTagContent::class, 'c')->where($qb->expr()->in('c.tagId', $tagIdArray));
        $qb->getQuery()->execute();
    }
}